==> haskell-with-utf8-1.1.0.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-7TyzxDIUDbO7dTC8HYyOK
key:                  with-utf8-1.1.0.0-7TyzxDIUDbO7dTC8HYyOK
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  771961fbe3fe6ad1e2c3fe2c496ab62b
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-7TyzxDIUDbO7dTC8HYyOK
depends:
    base-4.16.4.0 safe-exceptions-0.1.7.4-AkiwYZ9mDGR9FbZG7JSfe4
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-utf8-1.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-150d0Fzc2PwIIL0KliZmNL
key:                  with-utf8-1.1.0.0-150d0Fzc2PwIIL0KliZmNL
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  b34d6aa4b7a0356ac250d442fd3f6a26
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-150d0Fzc2PwIIL0KliZmNL
depends:
    base-4.16.4.0 safe-exceptions-0.1.7.4-BFjUnV2nLAB1SsdHVx5ZMJ
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
